@@ -33,12 +33,7 @@
 
 #include <libgnomecanvas/gnome-canvas.h>
 
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 #include <string.h>
 #include <math.h>
