@@ -51,10 +51,10 @@
 /* VOID:INT,BOOLEAN (gnome-printui-marshal.list:1) */
 void
 libgnomeprintui_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
-                                           GValue       *return_value,
+                                           GValue       *return_value G_GNUC_UNUSED,
                                            guint         n_param_values,
                                            const GValue *param_values,
-                                           gpointer      invocation_hint,
+                                           gpointer      invocation_hint G_GNUC_UNUSED,
                                            gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_BOOLEAN) (gpointer     data1,
@@ -94,10 +94,10 @@ libgnomeprintui_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
 /* VOID:UINT,UINT (gnome-printui-marshal.list:5) */
 void
 libgnomeprintui_marshal_VOID__UINT_UINT (GClosure     *closure,
-                                         GValue       *return_value,
+                                         GValue       *return_value G_GNUC_UNUSED,
                                          guint         n_param_values,
                                          const GValue *param_values,
-                                         gpointer      invocation_hint,
+                                         gpointer      invocation_hint G_GNUC_UNUSED,
                                          gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT) (gpointer     data1,
@@ -131,10 +131,10 @@ libgnomeprintui_marshal_VOID__UINT_UINT (GClosure     *closure,
 /* VOID:OBJECT,UINT (gnome-printui-marshal.list:6) */
 void
 libgnomeprintui_marshal_VOID__OBJECT_UINT (GClosure     *closure,
-                                           GValue       *return_value,
+                                           GValue       *return_value G_GNUC_UNUSED,
                                            guint         n_param_values,
                                            const GValue *param_values,
-                                           gpointer      invocation_hint,
+                                           gpointer      invocation_hint G_GNUC_UNUSED,
                                            gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_UINT) (gpointer     data1,
